package com.ruoyi.plant.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.plant.mapper.TCanteenCardMonthMapper;
import com.ruoyi.plant.domain.TCanteenCardMonth;
import com.ruoyi.plant.service.ITCanteenCardMonthService;

/**
 * 员工月刷卡统计Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-04-22
 */
@Service
public class TCanteenCardMonthServiceImpl implements ITCanteenCardMonthService 
{
    @Autowired
    private TCanteenCardMonthMapper tCanteenCardMonthMapper;

    /**
     * 查询员工月刷卡统计
     * 
     * @param id 员工月刷卡统计主键
     * @return 员工月刷卡统计
     */
    @Override
    public TCanteenCardMonth selectTCanteenCardMonthById(Long id)
    {
        return tCanteenCardMonthMapper.selectTCanteenCardMonthById(id);
    }

    /**
     * 查询员工月刷卡统计列表
     * 
     * @param tCanteenCardMonth 员工月刷卡统计
     * @return 员工月刷卡统计
     */
    @Override
    public List<TCanteenCardMonth> selectTCanteenCardMonthList(TCanteenCardMonth tCanteenCardMonth)
    {
        return tCanteenCardMonthMapper.selectTCanteenCardMonthList(tCanteenCardMonth);
    }

    /**
     * 新增员工月刷卡统计
     * 
     * @param tCanteenCardMonth 员工月刷卡统计
     * @return 结果
     */
    @Override
    public int insertTCanteenCardMonth(TCanteenCardMonth tCanteenCardMonth)
    {
        return tCanteenCardMonthMapper.insertTCanteenCardMonth(tCanteenCardMonth);
    }

    /**
     * 修改员工月刷卡统计
     * 
     * @param tCanteenCardMonth 员工月刷卡统计
     * @return 结果
     */
    @Override
    public int updateTCanteenCardMonth(TCanteenCardMonth tCanteenCardMonth)
    {
        return tCanteenCardMonthMapper.updateTCanteenCardMonth(tCanteenCardMonth);
    }

    /**
     * 批量删除员工月刷卡统计
     * 
     * @param ids 需要删除的员工月刷卡统计主键
     * @return 结果
     */
    @Override
    public int deleteTCanteenCardMonthByIds(Long[] ids)
    {
        return tCanteenCardMonthMapper.deleteTCanteenCardMonthByIds(ids);
    }

    /**
     * 删除员工月刷卡统计信息
     * 
     * @param id 员工月刷卡统计主键
     * @return 结果
     */
    @Override
    public int deleteTCanteenCardMonthById(Long id)
    {
        return tCanteenCardMonthMapper.deleteTCanteenCardMonthById(id);
    }
}
