package com.ruoyi.plant.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.plant.domain.TCanteenCardMonth;
import com.ruoyi.plant.service.ITCanteenCardMonthService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 员工月刷卡统计Controller
 * 
 * @author ruoyi
 * @date 2025-04-22
 */
@RestController
@RequestMapping("/plant/month")
public class TCanteenCardMonthController extends BaseController
{
    @Autowired
    private ITCanteenCardMonthService tCanteenCardMonthService;

    /**
     * 查询员工月刷卡统计列表
     */
    @PreAuthorize("@ss.hasPermi('plant:month:list')")
    @GetMapping("/list")
    public TableDataInfo list(TCanteenCardMonth tCanteenCardMonth)
    {
        startPage();
        List<TCanteenCardMonth> list = tCanteenCardMonthService.selectTCanteenCardMonthList(tCanteenCardMonth);
        return getDataTable(list);
    }

    /**
     * 导出员工月刷卡统计列表
     */
    @PreAuthorize("@ss.hasPermi('plant:month:export')")
    @Log(title = "员工月刷卡统计", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TCanteenCardMonth tCanteenCardMonth)
    {
        List<TCanteenCardMonth> list = tCanteenCardMonthService.selectTCanteenCardMonthList(tCanteenCardMonth);
        ExcelUtil<TCanteenCardMonth> util = new ExcelUtil<TCanteenCardMonth>(TCanteenCardMonth.class);
        util.exportExcel(response, list, "员工月刷卡统计数据");
    }

    /**
     * 获取员工月刷卡统计详细信息
     */
    @PreAuthorize("@ss.hasPermi('plant:month:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tCanteenCardMonthService.selectTCanteenCardMonthById(id));
    }

    /**
     * 新增员工月刷卡统计
     */
    @PreAuthorize("@ss.hasPermi('plant:month:add')")
    @Log(title = "员工月刷卡统计", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TCanteenCardMonth tCanteenCardMonth)
    {
        return toAjax(tCanteenCardMonthService.insertTCanteenCardMonth(tCanteenCardMonth));
    }

    /**
     * 修改员工月刷卡统计
     */
    @PreAuthorize("@ss.hasPermi('plant:month:edit')")
    @Log(title = "员工月刷卡统计", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TCanteenCardMonth tCanteenCardMonth)
    {
        return toAjax(tCanteenCardMonthService.updateTCanteenCardMonth(tCanteenCardMonth));
    }

    /**
     * 删除员工月刷卡统计
     */
    @PreAuthorize("@ss.hasPermi('plant:month:remove')")
    @Log(title = "员工月刷卡统计", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tCanteenCardMonthService.deleteTCanteenCardMonthByIds(ids));
    }
}
